#: Maps formats to file extensions;
#: They are registered in ckanext-dcor_schemas
DC_MIME_TYPES = {
    "RT-DC": ".rtdc",
    "DC": ".dc",  # more general
}

#: Valid values for resource "format"
VALID_FORMATS = sorted(DC_MIME_TYPES.keys()) + ["RT-FDC"]



import pathlib
import time

#: Content of the dummy file created when importing data.
DUMMY_BYTES = b"[Data import pending]"


def wait_for_resource(path):
    """Wait for resource if it is uploaded manually

    This function can be used by other plugins to ensure that
    a resource is available for processing.

    The ckanext-dcor_depot plugin imports data by uploading
    dummy files and then hard-linking to data on disk. Here
    we just check that the file is not a dummy file anymore.
    """
    path = pathlib.Path(path)
    timeout = 10
    t0 = time.time()
    ld = len(DUMMY_BYTES)
    while True:
        if time.time() - t0 > timeout:
            raise OSError("Data import seems to take too long!")
        elif not path.exists():
            time.sleep(0.05)
            continue
        elif path.stat().st_size < 2 * ld:
            with path.open("rb") as fd:
                data = fd.read(ld)
            if data == DUMMY_BYTES:
                # wait a bit
                time.sleep(0.01)
                continue
        else:
            # not a dummy file
            break



import os

from ckan.common import config


#: CKAN storage path (contains resources, uploaded group, user or organization
#: images)
CKAN_STORAGE = config.get('ckan.storage_path', "").rstrip("/")


def get_resource_path(rid, create_dirs=False):
    resources_path = CKAN_STORAGE + "/resources"
    pdir = "{}/{}/{}".format(resources_path, rid[:3], rid[3:6])
    path = "{}/{}".format(pdir, rid[6:])
    if create_dirs:
        try:
            os.makedirs(pdir)
            os.chown(pdir,
                     os.stat(resources_path).st_uid,
                     os.stat(resources_path).st_gid)
        except OSError:
            pass
    return path
